@@ -1,5 +1,5 @@
 package Git::Repository;
-$Git::Repository::VERSION = '1.313';
+$Git::Repository::VERSION = '1.315';
 use warnings;
 use strict;
 use 5.006;
@@ -210,18 +210,10 @@ sub version {
             =~ /git version (.*)/g )[0];
 }
 
-sub _version_eq {
-    my ( $v1, $v2 ) = @_;
-    my @v1 = split /\./, $v1;
-    my @v2 = split /\./, $v2;
-
-    return '' if @v1 != @v2;
-    $v1[$_] ne $v2[$_] and return '' for 0 .. $#v1;
-    return 1;
-}
-
 sub _version_gt {
     my ( $v1, $v2 ) = @_;
+    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
+
     my @v1 = split /\./, $v1;
     my @v2 = split /\./, $v2;
 
@@ -249,13 +241,17 @@ sub _version_gt {
 
 # every op is a combination of eq and gt
 sub version_eq {
-    my ( $r, $v, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    return _version_eq( $r->version(@o), $v );
+    my ( $r, $v2, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
+    my $v1 = $r->version(@o);
+    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
+    return $v1 eq $v2;
 }
 
 sub version_ne {
-    my ( $r, $v, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    return !_version_eq( $r->version(@o), $v );
+    my ( $r, $v2, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
+    my $v1 = $r->version(@o);
+    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
+    return $v1 ne $v2;
 }
 
 sub version_gt {
@@ -269,35 +265,29 @@ sub version_le {
 }
 
 sub version_lt {
-    my ( $r, $v, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    my $V = $r->version(@o);
-    return !_version_eq( $V, $v )
-        && !_version_gt( $V, $v );
+    my ( $r, $v2, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
+    my $v1 = $r->version(@o);
+    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
+    return $v1 ne $v2
+        && !_version_gt( $v1, $v2 );
 }
 
 sub version_ge {
-    my ( $r, $v, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
-    my $V = $r->version(@o);
-    return _version_eq( $V, $v )
-        || _version_gt( $V, $v );
+    my ( $r, $v2, @o ) = ( shift, ( grep !ref, @_ )[0], grep ref, @_ );
+    my $v1 = $r->version(@o);
+    s/(?<=^1\.0\.)0([ab])$/$1^"P"/e for $v1, $v2; # aliases
+    return $v1 eq $v2
+        || _version_gt( $v1, $v2 );
 }
 
 1;
 
-# ABSTRACT: Perl interface to Git repositories
-
 __END__
 
-=pod
-
 =head1 NAME
 
 Git::Repository - Perl interface to Git repositories
 
-=head1 VERSION
-
-version 1.313
-
 =head1 SYNOPSIS
 
     use Git::Repository;
@@ -453,12 +443,18 @@ pointing to it, simply do it in two steps:
     # on the resulting repository
     $r = Git::Repository->new( ... );
 
+
 =head1 METHODS
 
-=for Pod::Coverage     create
+=begin Pod::Coverage
+
+    create
     repo_path
     wc_path
 
+=end Pod::Coverage
+
+
 L<Git::Repository> supports the following methods:
 
 =head2 command
@@ -545,11 +541,15 @@ The methods are:
 
 All those methods also accept an option hash, just like the others.
 
-Note that there are a small number of cases where the version comparison
-operators will I<not> compare versions correctly for I<very old> versions of
-Git. Typical example is C<1.0.0a gt 1.0.0> which should return true, but
-doesn't. This only matters in comparisons, only for version numbers prior to
-C<1.4.0-rc1> (June 2006), and only when the compared versions are very close.
+Note that in the C<git.git> repository, C<v1.0.1> and C<v1.0.2> are
+lightweight tags that points respectively to C<v1.0.0a> and C<v1.0.0b>.
+As of Git::Repository 1.314, the comparison code internally converts
+C<v1.0.0a> and C<v1.0.0b> to their numerical equivalent before performing
+the comparison.
+
+Prior to C<1.4.0-rc1> (June 2006), compiling a development version of git
+would lead C<git --version> to output C<1.x-GIT> (with C<x> in C<0 .. 3>),
+which would make comparing versions that are very close a futile exercise.
 
 Other issues exist when comparing development version numbers with one
 another. For example, C<1.7.1.1> is greater than both C<1.7.1.1.gc8c07>
@@ -665,6 +665,7 @@ Although it supports C<git init> and C<git clone>
 porcelain commands, and provides no way to control bidirectional commands
 (such as C<git commit-tree>).
 
+
 =head2 Git::Wrapper
 
 L<Git::Wrapper>
@@ -708,6 +709,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Git::Repository
 
+
 You can also look for information at:
 
 =over 4
@@ -730,23 +732,9 @@ L<http://search.cpan.org/dist/Git-Repository>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Git-Repository or by email to
-bug-git-repository@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-Philippe Bruhat (BooK) <book@cpan.org>
-
 =head1 COPYRIGHT
 
-Copyright 2010-2014 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2015 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
