@@ -1,5 +1,5 @@
 package Git::Repository::Command;
-$Git::Repository::Command::VERSION = '1.313';
+$Git::Repository::Command::VERSION = '1.315';
 use strict;
 use warnings;
 use 5.006;
@@ -172,8 +172,10 @@ sub final_output {
     $self->close;
 
     # fatal exit codes set by the 'fatal' option
+    # when working with fatal => '!0' it's helpful to be able to show the exit status
+    # so that specific exit codes can be made non-fatal if desired.
     if ( $self->options->{fatal}{ $self->exit } ) {
-        croak join( "\n", @errput ) || 'fatal: unknown git error';
+        croak join( "\n", @errput ) || 'fatal: unknown git error, exit status '.$self->exit;
     }
 
     # something else's wrong
@@ -190,19 +192,13 @@ sub final_output {
 
 1;
 
-# ABSTRACT: Command objects for running git
-
 __END__
 
-=pod
-
 =head1 NAME
 
 Git::Repository::Command - Command objects for running git
 
-=head1 VERSION
-
-version 1.313
+=pod
 
 =head1 SYNOPSIS
 
@@ -234,6 +230,7 @@ version 1.313
     # cut to the chase
     my ( $pid, $in, $out, $err ) = Git::Repository::Command->spawn(@cmd);
 
+
 =head1 DESCRIPTION
 
 L<Git::Repository::Command> is a class that actually launches a B<git>
@@ -335,6 +332,7 @@ keys in later hashes taking precedence over keys in earlier hashes.
 The L<Git::Repository::Command> object returned by C<new()> has a
 number of attributes defined (see below).
 
+
 =head2 close
 
     $cmd->close();
@@ -362,6 +360,7 @@ warnings. If the git sub-process exited with a status code listed in
 the C<fatal> option, it will C<die()>. The defaults fatal exit codes
 are C<128> (fatal error), and C<129> (usage message).
 
+
 =head2 Accessors
 
 The attributes of a L<Git::Repository::Command> object are also accessible
@@ -437,23 +436,9 @@ Win32 support for L<System::Command> through a quick round of edit
 (on my Linux box) and testing (on his Windows box) during the Perl QA
 Hackathon 2013 in Lancaster.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Git-Repository or by email to
-bug-git-repository@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-Philippe Bruhat (BooK) <book@cpan.org>
-
 =head1 COPYRIGHT
 
-Copyright 2010-2014 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2015 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
