@@ -1,5 +1,5 @@
 package Test::Git;
-$Test::Git::VERSION = '1.314';
+$Test::Git::VERSION = '1.315';
 use strict;
 use warnings;
 
@@ -67,20 +67,12 @@ sub test_repository {
 
 1;
 
-# ABSTRACT: Helper functions for test scripts using Git
-
 __END__
 
-=pod
-
 =head1 NAME
 
 Test::Git - Helper functions for test scripts using Git
 
-=head1 VERSION
-
-version 1.314
-
 =head1 SYNOPSIS
 
     use Test::More;
@@ -114,6 +106,7 @@ version 1.314
 L<Test::Git> provides a number of helpful functions when running test
 scripts that require the creation and management of a Git repository.
 
+
 =head1 EXPORTED FUNCTIONS
 
 =head2 has_git
@@ -134,6 +127,7 @@ if requirements are not met.
 Note that the C<test_requires_git> function provided by the
 L<Test::Requires::Git> module is much more flexible.
 
+
 =head2 test_repository
 
     test_repository( %options );
@@ -216,23 +210,9 @@ repository.
 
 L<Test::Requires::Git>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Git-Repository or by email to
-bug-git-repository@rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHOR
-
-Philippe Bruhat (BooK) <book@cpan.org>
-
 =head1 COPYRIGHT
 
-Copyright 2010-2014 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2015 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
